@@ -8,11 +8,12 @@
 #' @param to numeric time to plot to. Only relevant if \code{qi = "Hazard Rate"}.
 #' @param title the plot's main title.
 #' @param smoother what type of smoothing line to use to summarize the plotted coefficient.
-#' @param spalette colour palette for use in \code{qi = "Hazard Rate"}. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
-#' @param leg.name name of the stratified hazard rates legend. Only relevant if \code{qi = "Hazard Rate"}.
+#' @param spalette colour palette for when there are multiple sets of comparisons to plot. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
+#' @param legend specifies what type of legend to include (if applicable). The default is \code{legend = "legend"}. To hide the legend use \code{legend = FALSE}. See the \code{\link{discrete_scale}} for more details.
+#' @param leg.name name of the legend (if applicable).
 #' @param lcolour character string colour of the smoothing line. The default is hexadecimal colour \code{lcolour = '#2B8CBE'}. Only relevant if \code{qi = "First Difference"}.
-#' @param lsize size of the smoothing line. Default is 2. See \code{\link{ggplot2}}.
-#' @param pcolour character string colour of the simulated points for relative hazards. Default is hexadecimal colour \code{pcolour = '#A6CEE3'}. Only relevant if \code{qi = "First Difference"}.
+#' @param lsize size of the smoothing line. Default is 1. See \code{\link{ggplot2}}.
+#' @param pcolour character string colour of the simulated points or ribbons (when there are not multiple sets of simulations). Default is hexadecimal colour \code{pcolour = '#A6CEE3'}.
 #' @param psize size of the plotted simulation points. Default is \code{psize = 1}. See \code{\link{ggplot2}}.
 #' @param alpha point alpha (e.g. transparency) for the points or ribbons. Default is \code{alpha = 0.1}. See \code{\link{ggplot2}}.
 #' @param ribbons logical specifies whether or not to use summary ribbons of the simulations rather than plotting every simulation value as a point. If \code{ribbons = TRUE} a plot will be created with shaded areas ('ribbons') for the minimum and maximum simulation values (i.e. the middle interval set with \code{qi} in \code{\link{coxsimPoly}}) as well as the central 50 percent of this area. It also plots a line for the median value of the full area, so values in \code{smoother} are ignored. One of the key advantages of using ribbons rather than points is that it creates plots with smaller file sizes.
@@ -39,11 +40,15 @@
 #' # Simulate simpoly Hazard Ratio with spin probibility interval
 #' # Sim2 <- coxsimPoly(M1, b = "natreg", qi = "Hazard Ratio", 
 #' #           pow = 3, Xj = seq(1, 150, by = 5), spin = TRUE)
+#'
+#' # Sim3 <- coxsimPoly(M1, b = "natreg", qi = "Hazard Rate", 
+#' #           pow = 3, Xj = c(1, 150))
 #' 
 #' # Plot simulations
 #' simGG(Sim1)
 #' # dontrun
-#' # simGG(Sim2)
+#' # simGG(Sim2, ribbons = TRUE)
+#' # simGG(Sim3, ribbons = TRUE)
 #'
 #' @details Uses \link{ggplot2} to plot the quantities of interest from \code{simpoly} objects. 
 #'
@@ -55,12 +60,15 @@
 #' @method simGG simpoly
 #' @S3method simGG simpoly
 
-simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", leg.name = "", lcolour = "#2B8CBE", lsize = 2, pcolour = "#A6CEE3", psize = 1, alpha = 0.1, ribbons = FALSE, ...)
+simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", legend = "legend", leg.name = "", lcolour = "#2B8CBE", lsize = 1, pcolour = "#A6CEE3", psize = 1, alpha = 0.1, ribbons = FALSE, ...)
 {
   Time <- HRValue <- HRate <- Xj <- QI <- Lower50 <- Upper50 <- Min <- Max <- Median <- NULL
   if (!inherits(obj, "simpoly")){
     stop("must be a simpoly object")
   }
+  if (isTRUE(ribbons) & smoother != "auto"){
+    message("The smoother argument is ignored if ribbons = TRUE. Central tendency summarised with the median.")
+  }
   # Find quantity of interest
   qi <- class(obj)[[2]]
 
@@ -89,18 +97,18 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_smooth(method = smoother, size = lsize, se = FALSE) +
           facet_grid(.~ Strata) +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
       } else if (is.null(obj$strata)){
           ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
             geom_point(shape = 21, alpha = I(alpha), size = psize) +
             geom_smooth(method = smoother, size = lsize, se = FALSE) +
-            scale_colour_brewer(palette = spalette, name = leg.name) +
+            scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
             xlab(xlab) + ylab(ylab) +
             ggtitle(title) +
-            guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+            #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
             theme_bw(base_size = 15)
     }
     } else if (qi == "First Difference"){
@@ -110,7 +118,7 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_hline(aes(yintercept = 0), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
     } else if (qi == "Hazard Ratio" | qi == "Relative Hazard"){
       ggplot(obj, aes(Xj, QI)) +
@@ -119,7 +127,7 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_hline(aes(yintercept = 1), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
           ggtitle(title) +
-          guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
     }
   }
@@ -135,10 +143,10 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
           geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) +
           facet_grid(. ~ Strata) +
           xlab(xlab) + ylab(ylab) +
-          scale_colour_brewer(palette = spalette, name = leg.name) +
-          scale_fill_brewer(palette = spalette, name = leg.name) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) +
           ggtitle(title) +
-              guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
       } else if (is.null(obj$Strata)){
       obj <- MinMaxLines(df = obj, hr = TRUE)
@@ -150,7 +158,7 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
             scale_fill_brewer(palette = spalette, name = leg.name) +
             xlab(xlab) + ylab(ylab) +
             ggtitle(title) +
-            guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+            #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
             theme_bw(base_size = 15)
     }
     } else if (qi == "First Difference"){
@@ -162,7 +170,7 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
         geom_hline(aes(yintercept = 0), linetype = "dotted") +
         xlab(xlab) + ylab(ylab) +
         ggtitle(title) +
-        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
             theme_bw(base_size = 15)
     } else if (qi == "Hazard Ratio" | qi == "Relative Hazard"){
       obj <- MinMaxLines(df = obj)
@@ -173,7 +181,7 @@ simGG.simpoly <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
         geom_hline(aes(yintercept = 1), linetype = "dotted") +
         xlab(xlab) + ylab(ylab) +
         ggtitle(title) +
-        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
         theme_bw(base_size = 15)
     }
     )  
